@@ -1,6 +1,6 @@
 // STL
 #include <iostream>
-#include <algorithm> // random_shuffle, reverse, sort, ...
+#include <algorithm>
 #include <cmath>
 
 // SCYTHE
@@ -13,10 +13,11 @@
 #include "stat.h" 
 #include "smath.h" 
 // R interface
-#include <R.h>           // needed to use Rprintf()
-#include <R_ext/Utils.h> // needed to allow user interrupts
+#include <R.h>           
+#include <R_ext/Utils.h>
 #include <Rdefines.h>
 #include <Rinternals.h>
+//
 #include "cumres.h"
 #include "extra.h"
 
@@ -71,26 +72,25 @@ Matrix<double> Whatfcov_crr(const unsigned &k,
 }
 
 extern "C" {
-  void Wfcovcrr(const int *R, // Number of realizations
-		 const unsigned *n, // Number of individuals
+  void Wfcovcrr(const int *R,
+		 const unsigned *n,
      const unsigned *m,
 		 const unsigned *nd,
-     const unsigned *ncom, // Number of interest events
-     const unsigned *nc, // Number of censory times
-		 const unsigned *p, // Number of  parameters
+     const unsigned *ncom,
+     const unsigned *nc,
+		 const unsigned *p,
      const unsigned *l_data,
      const double *G_data,
      const unsigned long *seed,
      const double *X_data_sort,
-		 const double *beta_data,  // nxp, parameter vector
+		 const double *beta_data,
 		 const double *time_data, // 
      const unsigned *index_otime_data,
 		 const unsigned *index_dtimes_data,
-     const unsigned *index_comptimes_data,// interest events times
-     const unsigned *index_censtimes_data, // censory times
-		 const double *X_data,  // nxp, Design matrix
+     const unsigned *index_comptimes_data,
+     const unsigned *index_censtimes_data,
+		 const double *X_data,
      const unsigned *index_ox_data,
-		 const double *Mt_data, // Martingale residuals
 		 const unsigned *plotnum,
      const unsigned *type_test_num,
 		 double *KS,
@@ -227,7 +227,7 @@ extern "C" {
   }
  
   Matrix<double> Itprep = multCol(S_2, t(1/S_0)); 
-  Itprep = Itprep-E_2; // Martinussen & Scheike p. 184
+  Itprep = Itprep-E_2;
   Matrix<double>It=multCol(Itprep,t(dN));
   It=cumsum(It);  
   Matrix<double> Itau = It(*m-1,_); Itau.resize(*p,*p);
@@ -304,8 +304,6 @@ extern "C" {
     Iz=t(Izprept);
   
     /*Calcul de Itz*/
-
-   /*Calcul de Itz*/
     
     Matrix<double>Itz(l[k],*p);
     for (unsigned c=0; c<l[k]; c++){
@@ -449,4 +447,4 @@ extern "C" {
       }
     }    
 	}  
-} // extern "C"
+}
